@@ -94,27 +94,23 @@ where
     R: Resolve,
 {
     fn resolve(&self, base: &FileName, src: &str) -> Result<FileName, Error> {
-        if src.starts_with(".") {
-            if src == ".." || src.starts_with("./") || src.starts_with("../") {
-                return self
-                    .inner
-                    .resolve(base, src)
-                    .context("not processed by tsc resolver because it's relative import");
-            }
+        if src.starts_with('.') && (src == ".." || src.starts_with("./") || src.starts_with("../"))
+        {
+            return self
+                .inner
+                .resolve(base, src)
+                .context("not processed by tsc resolver because it's relative import");
         }
 
-        match base {
-            FileName::Real(v) => {
-                if v.components().any(|c| match c {
-                    Component::Normal(v) => v == "node_modules",
-                    _ => false,
-                }) {
-                    return self.inner.resolve(base, src).context(
-                        "not processed by tsc resolver because base module is in node_modules",
-                    );
-                }
+        if let FileName::Real(v) = base {
+            if v.components().any(|c| match c {
+                Component::Normal(v) => v == "node_modules",
+                _ => false,
+            }) {
+                return self.inner.resolve(base, src).context(
+                    "not processed by tsc resolver because base module is in node_modules",
+                );
             }
-            _ => {}
         }
 
         // https://www.typescriptlang.org/docs/handbook/module-resolution.html#path-mapping
@@ -196,12 +192,11 @@ where
 }
 
 fn compile_regex(src: String) -> Regex {
-    static CACHE: Lazy<DashMap<String, Regex, ahash::RandomState>> =
-        Lazy::new(|| Default::default());
+    static CACHE: Lazy<DashMap<String, Regex, ahash::RandomState>> = Lazy::new(Default::default);
 
     if !CACHE.contains_key(&*src) {
         // Create capture group
-        let regex_pat = src.replace("*", "(.*)");
+        let regex_pat = src.replace('*', "(.*)");
         let re = Regex::new(&regex_pat).unwrap_or_else(|err| {
             panic!("failed to compile `{}` as a pattern: {:?}", regex_pat, err)
         });
